@@ -32,7 +32,7 @@
 #' @references Montgomerie R (2006) Analyzing colors. In: Hill G, McGraw K (eds) 
 #' Bird coloration. Harvard University Press, Cambridge, pp 90-147.
 
-aggplot <- function(rspecdata, by, FUN.center = mean, FUN.error = sd, 
+aggplot <- function(rspecdata, by = NULL, FUN.center = mean, FUN.error = sd, 
                     lcol = NULL, shadecol = NULL, alpha = 0.2, ...) {
 
 if (is.numeric(by))
@@ -40,8 +40,8 @@ if (is.numeric(by))
     stop('Cannot group single spectra (use plot instead)')
 
 #take aggregated data
-cntplotspecs <- aggspec(rspecdata,by=by, FUN=FUN.center)
-errplotspecs <- aggspec(rspecdata, by=by, FUN=FUN.error)
+cntplotspecs <- aggspec(rspecdata, by = by, FUN = FUN.center)
+errplotspecs <- aggspec(rspecdata, by = by, FUN = FUN.error)
 
 # make wavelength vector
 wl_index <- which(names(rspecdata)=='wl')
@@ -82,11 +82,14 @@ if (is.null(arg$ylab))
   arg$ylab <- "Reflectance (%)"
 
 # coloring for overlay plot & others
+if (!is.null(arg$lty))
+  lty <- arg$lty
+
 if (is.null(arg$lty))
   lty <- 1
 
-# if (length(lty) < ncol(cntplotspecs))
-#   lty <- rep(lty, ncol(cntplotspecs))
+if (length(lty) < ncol(cntplotspecs))
+   lty <- rep(lty, ncol(cntplotspecs))
 
 if (length(shadecol) < ncol(cntplotspecs))
   shadecol <- rep(shadecol, ncol(cntplotspecs))
@@ -142,6 +145,7 @@ do.call(polygon, arg)
   arg$x <- wl
   arg$y <- cntplotspecs[, 1]
   arg$type <- 'l'
+  arg$lty <- lty[1]
 
   do.call(lines, arg)
 
@@ -149,9 +153,9 @@ do.call(polygon, arg)
     for (i in 2:ncol(cntplotspecs)){
       arg$y <- cntplotspecs[, i]
       arg$col <- lcol[i]
-      # arg$lty <- lty[i]
+      arg$lty <- lty[i]
       do.call(lines, arg)
     }
   }
 
-}
\ No newline at end of file
+}
