@@ -6,7 +6,10 @@
 #' @param vismodeldata (required) quantum catch color data. Can be either the result
 #' from \code{\link{vismodel}} or independently calculated data (in the form of a data frame
 #' with four columns, representing the avian cones).
-#' @param qcatch quantum catch values to use in the model:
+#' @param qcatch if the object is of class \code{vismodel}, such as one generated using 
+#' \code{pavo}, this argument is ignored. If the object is a data frame of quantal catches 
+#' from another source, this argument is used to specify what type of quantum catch is being 
+#' used, so that the noise can be calculated accordingly: 
 #' \itemize{
 #' \item \code{Qi}: Quantum catch for each photoreceptor (default)
 #' \item \code{fi}: Quantum catch according to Fechner law (the signal of the receptor
@@ -18,6 +21,10 @@
 #' \item \code{tri}: Trichromatic color vision
 #' \item \code{di}: Dichromatic color vision
 #' }
+#' @param subset If only some of the comparisons should be returned, a character vector of 
+#' length 1 or 2 can be provided, indicating which samples are desired. The subset vector 
+#' must match the labels of the imput samples, but partial matching (and regular expressions) 
+#' are supported.
 #' @param achro logical. If \code{TRUE}, last column of the data frame is used to calculate 
 #' the achromatic contrast, with noise based on the Weber fraction calculated using \code{n4}
 #' @param n1,n2,n3,n4 tetrachromatic photoreceptor densities for u, s, m & l (default to 
@@ -45,40 +52,43 @@
 #' @examples \dontrun{
 #' data(sicalis)
 #' vis.sicalis <- vismodel(sicalis, visual='avg.uv', relative=FALSE)
-#' coldist.sicalis <- coldist(vis.sicalis, qcatch='fi', vis='tetra')}
+#' coldist.sicalis <- coldist(vis.sicalis, vis='tetra')}
 #' @author Rafael Maia \email{rm72@@zips.uakron.edu}
 #' @references Vorobyev, M., Osorio, D., Bennett, A., Marshall, N., & Cuthill, I. (1998). Tetrachromacy, oil droplets and bird plumage colours. Journal Of Comparative Physiology A-Neuroethology Sensory Neural And Behavioral Physiology, 183(5), 621-633.
 #' @references Hart, N. S. (2001). The visual ecology of avian photoreceptors. Progress In Retinal And Eye Research, 20(5), 675-703.
 #' @references Endler, J. A., & Mielke, P. (2005). Comparing entire colour patterns as birds see them. Biological Journal Of The Linnean Society, 86(4), 405-431.
 
-#ToDo: Add Neural Noise model
-#ToDo: make luminance contrast calculation optional
 
-coldist <-function(vismodeldata, qcatch=c('fi', 'Qi'), 
+coldist <-function(vismodeldata, qcatch=c('Qi','fi'),
                   vis=c('tetra', 'tri', 'di'), 
-                  noise=c('neural','quantum'), achro=TRUE,
+                  noise=c('neural','quantum'), subset=NULL,
+                  achro=TRUE,
                   n1=1, n2=2, n3=2, n4=4, v=0.1)
 {
 
-if(class(vismodeldata)=='vismodel'){
-	qcatch <- match.arg(qcatch)
-#	dat <- data.frame(vismodeldata[qcatch])
-	dat <- as.matrix(data.frame(vismodeldata[qcatch]))
-	colnames(dat) <- gsub(paste(qcatch,'.',sep=''),'',colnames(dat))
+if('vismodel' %in% class(vismodeldata)){
+	dat <- as.matrix(vismodeldata)
+	qcatch <- attr(vismodeldata, 'qcatch')
+#	colnames(dat) <- gsub(paste(qcatch,'.',sep=''),'',colnames(dat))
 	
-	qndat <- as.matrix(vismodeldata$Qi)
-	
-	if(attr(vismodeldata,'relative'))
-	  warning('Quantum catch are relative, distances may not be meaningful')
+  if(attr(vismodeldata, 'qcatch') == 'Qi')
+    qndat <- as.matrix(vismodeldata)
+
+  if(attr(vismodeldata, 'qcatch') == 'fi')
+    qndat <- as.matrix(exp(vismodeldata))
+
+  if(attr(vismodeldata,'relative'))
+    warning('Quantum catch are relative, distances may not be meaningful')
 	
   }else{
 	qcatch <- match.arg(qcatch)
   	dat <- as.matrix(vismodeldata)
   	rownames(dat) <- rownames(vismodeldata)
   	colnames(dat) <- colnames(vismodeldata)
+  	
   	}
 
-if(class(vismodeldata)!='vismodel' && noise=='quantum')
+if(!'vismodel' %in% class(vismodeldata) && noise=='quantum')
   stop('Object must be of class vismodel to calculate quantum noise model')
 
 noise <- match.arg(noise)
@@ -94,8 +104,6 @@ w2e <- v/sqrt(n2)
 w3e <- v/sqrt(n3)
 w4e <- v/sqrt(n4)
 
-
-# ToDo: this can be later subset if the user doesn't want all comparisons
 pairsid <- t(combn(nrow(dat),2))
 
 patch1 <- row.names(dat)[pairsid[,1]]
@@ -104,19 +112,19 @@ patch2 <- row.names(dat)[pairsid[,2]]
 res <- data.frame(patch1, patch2)
 
 if (vis=='di' & noise=='neural'){
-res$di.dS <- apply(pairsid,1,function(x) 
+res$dS <- apply(pairsid,1,function(x) 
   didistcalc(dat[x[1],], dat[x[2],], 
   w1=w1e, w2=w2e) )
 }
 
 if (vis=='tri' & noise=='neural'){
-res$tri.dS <- apply(pairsid,1,function(x) 
+res$dS <- apply(pairsid,1,function(x) 
   trdistcalc(dat[x[1],], dat[x[2],], 
   w1=w1e, w2=w2e, w3=w3e) )
 }
 
 if (vis=='tetra' & noise=='neural'){
-res$tetra.dS <- apply(pairsid,1,function(x) 
+res$dS <- apply(pairsid,1,function(x) 
   ttdistcalc(dat[x[1],], dat[x[2],], 
   w1=w1e, w2=w2e, w3=w3e, w4=w4e) )
 }
@@ -132,21 +140,21 @@ res$dL <- apply(pairsid,1,function(x)
 
 
 if (vis=='di' & noise=='quantum'){
-res$di.dS <- apply(pairsid,1,function(x) 
+res$dS <- apply(pairsid,1,function(x) 
   qn.didistcalc(dat[x[1],], dat[x[2],], 
   qndat[x[1],], qndat[x[2],], 
   n1=n1, n2=n2, v=v) )
 }
 
 if (vis=='tri' & noise=='quantum'){
-res$tri.dS <- apply(pairsid,1,function(x) 
+res$dS <- apply(pairsid,1,function(x) 
   qn.trdistcalc(dat[x[1],], dat[x[2],],
   qndat[x[1],], qndat[x[2],], 
   n1=n1, n2=n2, n3=n3, v=v ) )
 }
 
 if (vis=='tetra' & noise=='quantum'){
-res$tetra.dS <- apply(pairsid,1,function(x) 
+res$dS <- apply(pairsid,1,function(x) 
   qn.ttdistcalc(dat[x[1],], dat[x[2],],
   qndat[x[1],], qndat[x[2],], 
   n1=n1, n2=n2, n3=n3, n4=n4, v=v) )
@@ -161,5 +169,35 @@ res$dL <- apply(pairsid,1,function(x)
 
 nams2 <- with(res, unique(c(as.character(patch1), as.character(patch2))))
 
+# Subsetting samples
+
+if(length(subset)==1){
+  
+  condition1 <- grep(subset, res$patch1)
+  condition2 <- grep(subset, res$patch2)
+
+  subsamp <- unique(c(condition1, condition2))
+  
+  res <- res[subsamp,]	
+ }
+  
+if(length(subset)==2){
+  condition1 <- intersect(grep(subset[1], res$patch1), 
+    grep(subset[2],res$patch2) )
+	
+  condition2 <- intersect(grep(subset[2], res$patch1), 
+    grep(subset[1],res$patch2) )
+	
+  subsamp <- unique(c(condition1, condition2))
+  
+  res <- res[subsamp,]	
+}
+
+if(length(subset) > 2){
+  stop('Too many subsetting conditions; one or two allowed.')
+}
+
+row.names(res) <- 1:dim(res)[1]
+
 res
-}
\ No newline at end of file
+}
