@@ -26,7 +26,7 @@
 #' @seealso \code{\link{as.rspec}}, \code{\link{aggspec}}
 
 merge.rspec <- function(x, y, by='wl', ...) {
-  if (!(is.rspec(x)&&is.rspec(y))) {stop("One ore more invalid rspec objects")}
+  if (!(is.rspec(x)&&is.rspec(y))) {stop("One or more invalid rspec objects")}
   if (!(any(names(x)=='wl')&any(names(y)=='wl'))) {
     stop("Cannot find valid 'wl' column in one or both input objects")
   }
